You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@poi.apache.org by on...@apache.org on 2016/08/22 18:25:45 UTC

svn commit: r1757239 - /poi/trunk/src/java/org/apache/poi/ss/usermodel/Cell.java

Author: onealj
Date: Mon Aug 22 18:25:45 2016
New Revision: 1757239

URL: http://svn.apache.org/viewvc?rev=1757239&view=rev
Log:
bug 59791: add @Removal tags to Cell.CELL_TYPE_* constants, deprecated by CellType enum

Modified:
    poi/trunk/src/java/org/apache/poi/ss/usermodel/Cell.java

Modified: poi/trunk/src/java/org/apache/poi/ss/usermodel/Cell.java
URL: http://svn.apache.org/viewvc/poi/trunk/src/java/org/apache/poi/ss/usermodel/Cell.java?rev=1757239&r1=1757238&r2=1757239&view=diff
==============================================================================
--- poi/trunk/src/java/org/apache/poi/ss/usermodel/Cell.java (original)
+++ poi/trunk/src/java/org/apache/poi/ss/usermodel/Cell.java Mon Aug 22 18:25:45 2016
@@ -24,6 +24,7 @@ import org.apache.poi.ss.formula.Formula
 import org.apache.poi.ss.util.CellAddress;
 import org.apache.poi.ss.util.CellRangeAddress;
 import org.apache.poi.util.Internal;
+import org.apache.poi.util.Removal;
 
 /**
  * High level representation of a cell in a row of a spreadsheet.
@@ -46,6 +47,7 @@ public interface Cell {
      * @see #getCellType()
      * @deprecated POI 3.15 beta 3. Use {@link CellType#NUMERIC} instead.
      */
+    @Removal(version="4.0")
     int CELL_TYPE_NUMERIC = 0; //CellType.NUMERIC.getCode();
 
     /**
@@ -54,6 +56,7 @@ public interface Cell {
      * @see #getCellType()
      * @deprecated POI 3.15 beta 3. Use {@link CellType#STRING} instead.
      */
+    @Removal(version="4.0")
     int CELL_TYPE_STRING = 1; //CellType.STRING.getCode();
 
     /**
@@ -62,6 +65,7 @@ public interface Cell {
      * @see #getCellType()
      * @deprecated POI 3.15 beta 3. Use {@link CellType#FORMULA} instead.
      */
+    @Removal(version="4.0")
     int CELL_TYPE_FORMULA = 2; //CellType.FORMULA.getCode();
 
     /**
@@ -70,6 +74,7 @@ public interface Cell {
      * @see #getCellType()
      * @deprecated POI 3.15 beta 3. Use {@link CellType#BLANK} instead.
      */
+    @Removal(version="4.0")
     int CELL_TYPE_BLANK = 3; //CellType.BLANK.getCode();
 
     /**
@@ -78,6 +83,7 @@ public interface Cell {
      * @see #getCellType()
      * @deprecated POI 3.15 beta 3. Use {@link CellType#BOOLEAN} instead.
      */
+    @Removal(version="4.0")
     int CELL_TYPE_BOOLEAN = 4; //CellType.BOOLEAN.getCode();
 
     /**
@@ -86,6 +92,7 @@ public interface Cell {
      * @see #getCellType()
      * @deprecated POI 3.15 beta 3. Use {@link CellType#ERROR} instead.
      */
+    @Removal(version="4.0")
     int CELL_TYPE_ERROR = 5; //CellType.ERROR.getCode();
 
     /**
@@ -136,6 +143,7 @@ public interface Cell {
      * @see CellType#ERROR
      * @deprecated POI 3.15 beta 3. Use {@link #setCellType(CellType)} instead.
      */
+    @Removal(version="4.0")
     void setCellType(int cellType);
     /**
      * Set the cells type (numeric, formula or string).
@@ -155,7 +163,7 @@ public interface Cell {
     /**
      * Return the cell type.
      * 
-     * Will return {@link CellType} in a future version of POI.
+     * Will return {@link CellType} in version 4.0 of POI.
      * For forwards compatibility, do not hard-code cell type literals in your code.
      *
      * @return the cell type
@@ -168,9 +176,10 @@ public interface Cell {
      * @return the cell type
      * @since POI 3.15 beta 3
      * @deprecated POI 3.15 beta 3
      * Will be deleted when we make the CellType enum transition. See bug 59791.
      */
     @Internal(since="POI 3.15 beta 3")
+    @Removal(version="4.2")
     CellType getCellTypeEnum();
     
     /**
@@ -192,7 +201,7 @@ public interface Cell {
      * on the cached value of the formula
      * @since POI 3.15 beta 3
      * @deprecated POI 3.15 beta 3
      * Will be deleted when we make the CellType enum transition. See bug 59791.
      */
     @Internal(since="POI 3.15 beta 3")
     CellType getCachedFormulaResultTypeEnum();



---------------------------------------------------------------------
@@ -168,9 +176,10 @@ public interface Cell {
      * @since POI 3.15 beta 3
      * @deprecated POI 3.15 beta 3
-     * Will be deleted when we make the CellType enum transition. See bug 59791.
+     * Will be renamed to <code>getCellType()</code> when we make the CellType enum transition in POI 4.0. See bug 59791.
      */
     @Internal(since="POI 3.15 beta 3")
@@ -192,7 +201,7 @@ public interface Cell {
      * @since POI 3.15 beta 3
      * @deprecated POI 3.15 beta 3
-     * Will be deleted when we make the CellType enum transition. See bug 59791.
+     * Will be renamed to <code>getCachedFormulaResultType()</code> when we make the CellType enum transition in POI 4.0. See bug 59791.
      */
     @Internal(since="POI 3.15 beta 3")
To unsubscribe, e-mail: commits-unsubscribe@poi.apache.org
For additional commands, e-mail: commits-help@poi.apache.org